diff --git a/Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_rdotoaod_grid.sh b/Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_rdotoaod_grid.sh
deleted file mode 100755
index 9d14548fac169cea4a3f6abf65c5f3c19cfeb0a7..0000000000000000000000000000000000000000
--- a/Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_rdotoaod_grid.sh
+++ /dev/null
@@ -1,33 +0,0 @@
-#!/bin/bash
-
-# art-description: Trigger MC pp v7 RDO to AOD test
-# art-type: grid
-# art-include: 21.0/Athena
-# art-include: 21.3/Athena
-# art-include: master/Athena
-# art-include: 21.1/AthenaP1
-# art-output: *check*
-# art-output: HLTChain.txt
-# art-output: HLTTE.txt
-# art-output: L1AV.txt
-# art-output: HLTconfig*.xml
-# art-output: L1Topoconfig*.xml
-# art-output: LVL1config*.xml
-# art-output: *.log
-# art-output: *.root
-# art-output: ntuple.pmon.gz
-# art-output: *perfmon*
-# art-output: TotalEventsProcessed.txt
-# art-output: AOD.pool.root.checkFile0
-# art-output: AOD.pool.root.checkFiletrigSize.txt
-# art-output: *.regtest.new
-
-export NAME="mc_pp_v7_rdotoaod_grid"
-export COST_MONITORING="False"
-export TEST="TrigAnalysisTest"
-export MENU="MC_pp_v7"
-export EVENTS="100"
-export JOBOPTION="TrigAnalysisTest/testAthenaTrigRDOtoAOD.py"
-
-source exec_athena_art_trigger_validation.sh
-source exec_art_triggertest_post.sh
diff --git a/Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_rdotoesdaod_build.sh b/Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_rdotoesdaod_build.sh
deleted file mode 100755
index 1c7ba8a7adb0ddf73d675887fed6fb86c8e92422..0000000000000000000000000000000000000000
--- a/Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_rdotoesdaod_build.sh
+++ /dev/null
@@ -1,32 +0,0 @@
-#!/bin/bash
-
-# art-description: Trigger MC pp v7 RDO to ESD and AOD test, plus extra tests using these files
-# art-type: build
-# art-include: 21.0/Athena
-# art-include: 21.3/Athena
-# art-include: master/Athena
-# art-include: 21.1/AthenaP1
-# art-output: *check*
-# art-output: HLTChain.txt
-# art-output: HLTTE.txt
-# art-output: L1AV.txt
-# art-output: HLTconfig*.xml
-# art-output: L1Topoconfig*.xml
-# art-output: LVL1config*.xml
-# art-output: *.log
-# art-output: *.root
-# art-output: ntuple.pmon.gz
-# art-output: *perfmon*
-# art-output: TotalEventsProcessed.txt
-# art-output: *.regtest.new
-
-export NAME="mc_pp_v7_rdotoesdaod_build"
-export COST_MONITORING="False"
-export TEST="TrigAnalysisTest"
-export MENU="MC_pp_v7"
-export EVENTS="3"
-export JOBOPTION="TrigAnalysisTest/testAthenaTrigRDOtoESDAOD.py"
-
-source exec_athena_art_trigger_validation.sh
-source exec_art_triggertest_post.sh
-source exec_art_triganalysistest_post.sh
diff --git a/Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_rdotoesdaod_grid.sh b/Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_rdotoesdaod_grid.sh
deleted file mode 100755
index 892f6ea67c8e39e4fecd492418257d9b8f782883..0000000000000000000000000000000000000000
--- a/Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_rdotoesdaod_grid.sh
+++ /dev/null
@@ -1,35 +0,0 @@
-#!/bin/bash
-
-# art-description: Trigger MC pp v7 RDO to ESD and AOD test, plus extra tests using these files
-# art-type: grid
-# art-include: 21.0/Athena
-# art-include: 21.3/Athena
-# art-include: master/Athena
-# art-include: 21.1/AthenaP1
-# art-output: *check*
-# art-output: HLTChain.txt
-# art-output: HLTTE.txt
-# art-output: L1AV.txt
-# art-output: HLTconfig*.xml
-# art-output: L1Topoconfig*.xml
-# art-output: LVL1config*.xml
-# art-output: *.log
-# art-output: *.root
-# art-output: ntuple.pmon.gz
-# art-output: *perfmon*
-# art-output: TotalEventsProcessed.txt
-# art-output: AOD.pool.root.checkFile0
-# art-output: AOD.pool.root.checkFiletrigSize.txt
-# art-output: *.regtest.new
-
-
-export NAME="mc_pp_v7_rdotoesdaod_grid"
-export COST_MONITORING="False"
-export TEST="TrigAnalysisTest"
-export MENU="MC_pp_v7"
-export EVENTS="100"
-export JOBOPTION="TrigAnalysisTest/testAthenaTrigRDOtoESDAOD.py"
-
-source exec_athena_art_trigger_validation.sh
-source exec_art_triggertest_post.sh
-source exec_art_triganalysistest_post.sh
diff --git a/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_rdotobstoesd_build.sh b/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_rdotobstoesd_build.sh
deleted file mode 100755
index 4cba6c7df599b8529df494c2f8a81a0794494d4c..0000000000000000000000000000000000000000
--- a/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_rdotobstoesd_build.sh
+++ /dev/null
@@ -1,36 +0,0 @@
-#!/bin/bash
-
-# art-description: Trigger Physics pp v7 RDO to BS and BS to AOD test
-# art-type: build
-# art-include: 21.0/Athena
-# art-include: 21.3/Athena
-# art-include: master/Athena
-# art-include: 21.1/AthenaP1
-# art-output: *check*
-# art-output: HLTChain.txt
-# art-output: HLTTE.txt
-# art-output: L1AV.txt
-# art-output: HLTconfig*.xml
-# art-output: L1Topoconfig*.xml
-# art-output: LVL1config*.xml
-# art-output: *.log
-# art-output: *.root
-# art-output: ntuple.pmon.gz
-# art-output: *perfmon*
-# art-output: TotalEventsProcessed.txt
-# art-output: *.regtest.new
-
-export NAME="physics_pp_v7_rdotobstoesd_build"
-export COST_MONITORING="False"
-export TEST="TrigAnalysisTest"
-export MENU="Physics_pp_v7_primaries"
-export EVENTS="3"
-export JOBOPTION="TrigAnalysisTest/testAthenaTrigRDOtoBS.py"
-
-source exec_athena_art_trigger_validation.sh
-athena.py -c "jp.AthenaCommonFlags.BSRDOInput=['raw.data']" TrigAnalysisTest/testAthenaTrigBStoESD.py | tee ${JOB_LOG%%.*}2.${JOB_LOG#*.}
-echo "art-result: ${PIPESTATUS[0]} ${JOB_LOG%%.*}2"
-
-source exec_art_triggertest_post.sh
-
-
diff --git a/Trigger/TrigValidation/TriggerTest/test/test_data_physics_pp_v7_build.sh b/Trigger/TrigValidation/TriggerTest/test/test_data_physics_pp_v7_build.sh
deleted file mode 100755
index a351b19e96de361fcfc3fb1686a485d82e5baa16..0000000000000000000000000000000000000000
--- a/Trigger/TrigValidation/TriggerTest/test/test_data_physics_pp_v7_build.sh
+++ /dev/null
@@ -1,32 +0,0 @@
-#!/bin/bash
-
-# art-description: Physics v7 TriggerTest on data
-# art-type: build
-# art-include: 21.0/Athena
-# art-include: 21.3/Athena
-# art-include: master/Athena
-# art-output: HLTChain.txt
-# art-output: HLTTE.txt
-# art-output: L1AV.txt
-# art-output: HLTconfig_*.xml
-# art-output: L1Topoconfig*.xml
-# art-output: LVL1config*.xml
-# art-output: *.log
-# art-output: costMonitoring_*
-# art-output: *.root
-# art-output: ntuple.pmon.gz
-# art-output: *perfmon*
-# art-output: TotalEventsProcessed.txt
-# art-output: *.regtest.new
-
-export NAME="data_physics_pp_v7_build"
-export MENU="Physics_pp_v7"
-export EVENTS="100"
-export INPUT="data"
-
-# The flag below skips HLTTE and L1 counts checks, but keeps the HLTChain counts check.
-# This is needed because we run on data without rerunLvl1, so we only produce HLTChain counts.
-export SKIP_CHAIN_DUMP=2
-
-source exec_athena_art_trigger_validation.sh
-source exec_art_triggertest_post.sh
diff --git a/Trigger/TrigValidation/TriggerTest/test/test_data_physics_pp_v7_grid.sh b/Trigger/TrigValidation/TriggerTest/test/test_data_physics_pp_v7_grid.sh
deleted file mode 100755
index 0a8d5ffdd9c5fb6af98739497db076fa963bb20e..0000000000000000000000000000000000000000
--- a/Trigger/TrigValidation/TriggerTest/test/test_data_physics_pp_v7_grid.sh
+++ /dev/null
@@ -1,32 +0,0 @@
-#!/bin/bash
-
-# art-description: Physics v7 TriggerTest on data
-# art-type: grid
-# art-include: 21.0/Athena
-# art-include: 21.3/Athena
-# art-include: master/Athena
-# art-output: HLTChain.txt
-# art-output: HLTTE.txt
-# art-output: L1AV.txt
-# art-output: HLTconfig_*.xml
-# art-output: L1Topoconfig*.xml
-# art-output: LVL1config*.xml
-# art-output: *.log
-# art-output: costMonitoring_*
-# art-output: *.root
-# art-output: ntuple.pmon.gz
-# art-output: *perfmon*
-# art-output: TotalEventsProcessed.txt
-# art-output: *.regtest.new
-
-export NAME="data_physics_pp_v7_grid"
-export MENU="Physics_pp_v7"
-export EVENTS="1000"
-export INPUT="data"
-
-# The flag below skips HLTTE and L1 counts checks, but keeps the HLTChain counts check.
-# This is needed because we run on data without rerunLvl1, so we only produce HLTChain counts.
-export SKIP_CHAIN_DUMP=2
-
-source exec_athena_art_trigger_validation.sh
-source exec_art_triggertest_post.sh
diff --git a/Trigger/TrigValidation/TriggerTest/test/test_mc_pp_v7_build.sh b/Trigger/TrigValidation/TriggerTest/test/test_mc_pp_v7_build.sh
deleted file mode 100755
index 98e1edfe46c2eee8e0cff51a6ca5127ad6eec6e2..0000000000000000000000000000000000000000
--- a/Trigger/TrigValidation/TriggerTest/test/test_mc_pp_v7_build.sh
+++ /dev/null
@@ -1,29 +0,0 @@
-#!/bin/bash
-
-# art-description: MC v7 TriggerTest on MC
-# art-type: build
-# art-include: 21.1/AthenaP1
-# art-include: 21.0/Athena
-# art-include: 21.0-TrigMC/Athena
-# art-include: master/Athena
-# art-output: HLTChain.txt
-# art-output: HLTTE.txt
-# art-output: L1AV.txt
-# art-output: HLTconfig*.xml
-# art-output: L1Topoconfig*.xml
-# art-output: LVL1config*.xml
-# art-output: *.log
-# art-output: costMonitoring_*
-# art-output: *.root
-# art-output: ntuple.pmon.gz
-# art-output: *perfmon*
-# art-output: TotalEventsProcessed.txt
-# art-output: *.regtest.new
-
-export NAME="mc_pp_v7_build"
-export MENU="MC_pp_v7"
-export EVENTS="5"
-export COST_MONITORING="False"
-
-source exec_athena_art_trigger_validation.sh
-source exec_art_triggertest_post.sh
diff --git a/Trigger/TrigValidation/TriggerTest/test/test_mc_pp_v7_bulkmcprod_grid.sh b/Trigger/TrigValidation/TriggerTest/test/test_mc_pp_v7_bulkmcprod_grid.sh
deleted file mode 100755
index d38d95a92816948f86c2bfeda2f888500bd69a31..0000000000000000000000000000000000000000
--- a/Trigger/TrigValidation/TriggerTest/test/test_mc_pp_v7_bulkmcprod_grid.sh
+++ /dev/null
@@ -1,28 +0,0 @@
-#!/bin/bash
-
-# art-description: MC v7 tight TriggerTest on MC
-# art-type: grid
-# art-include: 21.1/AthenaP1
-# art-include: 21.0/Athena
-# art-include: 21.0-TrigMC/Athena
-# art-include: master/Athena
-# art-output: HLTChain.txt
-# art-output: HLTTE.txt
-# art-output: L1AV.txt
-# art-output: HLTconfig*.xml
-# art-output: L1Topoconfig*.xml
-# art-output: LVL1config*.xml
-# art-output: *.log
-# art-output: costMonitoring_*
-# art-output: *.root
-# art-output: ntuple.pmon.gz
-# art-output: *perfmon*
-# art-output: TotalEventsProcessed.txt
-# art-output: *.regtest.new
-
-export NAME="mc_pp_v7_bulkmcprod_grid"
-export MENU="MC_pp_v7_BulkMCProd_mc_prescale"
-export EVENTS="500"
-
-source exec_athena_art_trigger_validation.sh
-source exec_art_triggertest_post.sh
diff --git a/Trigger/TrigValidation/TriggerTest/test/test_mc_pp_v7_cpsampleprod_grid.sh b/Trigger/TrigValidation/TriggerTest/test/test_mc_pp_v7_cpsampleprod_grid.sh
deleted file mode 100755
index d952a7d80c6a63e576ddfecff36c37927832bfe6..0000000000000000000000000000000000000000
--- a/Trigger/TrigValidation/TriggerTest/test/test_mc_pp_v7_cpsampleprod_grid.sh
+++ /dev/null
@@ -1,29 +0,0 @@
-#!/bin/bash
-
-# art-description: MC v7 tight TriggerTest on MC
-# art-type: grid
-# art-include: 21.1/AthenaP1
-# art-include: 21.0/Athena
-# art-include: 21.3/Athena
-# art-include: 21.0-TrigMC/Athena
-# art-include: master/Athena
-# art-output: HLTChain.txt
-# art-output: HLTTE.txt
-# art-output: L1AV.txt
-# art-output: HLTconfig*.xml
-# art-output: L1Topoconfig*.xml
-# art-output: LVL1config*.xml
-# art-output: *.log
-# art-output: costMonitoring_*
-# art-output: *.root
-# art-output: ntuple.pmon.gz
-# art-output: *perfmon*
-# art-output: TotalEventsProcessed.txt
-# art-output: *.regtest.new
-
-export NAME="mc_pp_v7_cpsampleprod_grid"
-export MENU="MC_pp_v7_CPSampleProd_mc_prescale"
-export EVENTS="500"
-
-source exec_athena_art_trigger_validation.sh
-source exec_art_triggertest_post.sh
diff --git a/Trigger/TrigValidation/TriggerTest/test/test_mc_pp_v7_grid.sh b/Trigger/TrigValidation/TriggerTest/test/test_mc_pp_v7_grid.sh
deleted file mode 100755
index 92df649dcad064d07024912d10bcc8951e3b1463..0000000000000000000000000000000000000000
--- a/Trigger/TrigValidation/TriggerTest/test/test_mc_pp_v7_grid.sh
+++ /dev/null
@@ -1,29 +0,0 @@
-#!/bin/bash
-
-# art-description: MC v7 TriggerTest on MC
-# art-type: grid
-# art-include: 21.1/AthenaP1
-# art-include: 21.0/Athena
-# art-include: 21.3/Athena
-# art-include: 21.0-TrigMC/Athena
-# art-include: master/Athena
-# art-output: HLTChain.txt
-# art-output: HLTTE.txt
-# art-output: L1AV.txt
-# art-output: HLTconfig*.xml
-# art-output: L1Topoconfig*.xml
-# art-output: LVL1config*.xml
-# art-output: *.log
-# art-output: costMonitoring_*
-# art-output: *.root
-# art-output: ntuple.pmon.gz
-# art-output: *perfmon*
-# art-output: TotalEventsProcessed.txt
-# art-output: *.regtest.new
-
-export NAME="mc_pp_v7_grid"
-export MENU="MC_pp_v7"
-export EVENTS="500"
-
-source exec_athena_art_trigger_validation.sh
-source exec_art_triggertest_post.sh
diff --git a/Trigger/TrigValidation/TriggerTest/test/test_mc_pp_v7_loose_grid.sh b/Trigger/TrigValidation/TriggerTest/test/test_mc_pp_v7_loose_grid.sh
deleted file mode 100755
index 630cd4cc7f91347b19874c0030dd4b7614c78bfe..0000000000000000000000000000000000000000
--- a/Trigger/TrigValidation/TriggerTest/test/test_mc_pp_v7_loose_grid.sh
+++ /dev/null
@@ -1,30 +0,0 @@
-#!/bin/bash
-
-# art-description: MC v7 loose TriggerTest on MC
-# art-type: grid
-# art-include: 21.1/AthenaP1
-# art-include: 21.1-dev/AthenaP1
-# art-include: 21.0/Athena
-# art-include: 21.0-TrigMC/Athena
-# art-include: master/Athena
-# art-include: master/AthenaP1
-# art-output: HLTChain.txt
-# art-output: HLTTE.txt
-# art-output: L1AV.txt
-# art-output: HLTconfig*.xml
-# art-output: L1Topoconfig*.xml
-# art-output: LVL1config*.xml
-# art-output: *.log
-# art-output: costMonitoring_*
-# art-output: *.root
-# art-output: ntuple.pmon.gz
-# art-output: *perfmon*
-# art-output: TotalEventsProcessed.txt
-# art-output: *.regtest.new
-
-export NAME="mc_pp_v7_loose_grid"
-export MENU="MC_pp_v7_loose_mc_prescale"
-export EVENTS="500"
-
-source exec_athena_art_trigger_validation.sh
-source exec_art_triggertest_post.sh
diff --git a/Trigger/TrigValidation/TriggerTest/test/test_mc_pp_v7_tight_grid.sh b/Trigger/TrigValidation/TriggerTest/test/test_mc_pp_v7_tight_grid.sh
deleted file mode 100755
index ed2eb0decf079f36ca1926d4b95fdfa0799f6153..0000000000000000000000000000000000000000
--- a/Trigger/TrigValidation/TriggerTest/test/test_mc_pp_v7_tight_grid.sh
+++ /dev/null
@@ -1,30 +0,0 @@
-#!/bin/bash
-
-# art-description: MC v7 tight TriggerTest on MC
-# art-type: grid
-# art-include: 21.1/AthenaP1
-# art-include: 21.1-dev/AthenaP1
-# art-include: 21.0/Athena
-# art-include: 21.0-TrigMC/Athena
-# art-include: master/Athena
-# art-include: master/AthenaP1
-# art-output: HLTChain.txt
-# art-output: HLTTE.txt
-# art-output: L1AV.txt
-# art-output: HLTconfig*.xml
-# art-output: L1Topoconfig*.xml
-# art-output: LVL1config*.xml
-# art-output: *.log
-# art-output: costMonitoring_*
-# art-output: *.root
-# art-output: ntuple.pmon.gz
-# art-output: *perfmon*
-# art-output: TotalEventsProcessed.txt
-# art-output: *.regtest.new
-
-export NAME="mc_pp_v7_tight_grid"
-export MENU="MC_pp_v7_tight_mc_prescale"
-export EVENTS="500"
-
-source exec_athena_art_trigger_validation.sh
-source exec_art_triggertest_post.sh
diff --git a/Trigger/TrigValidation/TriggerTest/test/test_mc_pp_v7_triggervalidation_grid.sh b/Trigger/TrigValidation/TriggerTest/test/test_mc_pp_v7_triggervalidation_grid.sh
deleted file mode 100755
index 15932de08036ad4caa503d0ed89ea64a0bc2a416..0000000000000000000000000000000000000000
--- a/Trigger/TrigValidation/TriggerTest/test/test_mc_pp_v7_triggervalidation_grid.sh
+++ /dev/null
@@ -1,29 +0,0 @@
-#!/bin/bash
-
-# art-description: MC v7 tight TriggerTest on MC
-# art-type: grid
-# art-include: 21.1/AthenaP1
-# art-include: 21.0/Athena
-# art-include: 21.3/Athena
-# art-include: 21.0-TrigMC/Athena
-# art-include: master/Athena
-# art-output: HLTChain.txt
-# art-output: HLTTE.txt
-# art-output: L1AV.txt
-# art-output: HLTconfig*.xml
-# art-output: L1Topoconfig*.xml
-# art-output: LVL1config*.xml
-# art-output: *.log
-# art-output: costMonitoring_*
-# art-output: *.root
-# art-output: ntuple.pmon.gz
-# art-output: *perfmon*
-# art-output: TotalEventsProcessed.txt
-# art-output: *.regtest.new
-
-export NAME="mc_pp_v7_triggervalidation_grid"
-export MENU="MC_pp_v7_TriggerValidation_mc_prescale"
-export EVENTS="500"
-
-source exec_athena_art_trigger_validation.sh
-source exec_art_triggertest_post.sh
diff --git a/Trigger/TrigValidation/TriggerTest/test/test_physics_pp_v7_build.sh b/Trigger/TrigValidation/TriggerTest/test/test_physics_pp_v7_build.sh
deleted file mode 100755
index 981273336795f2711c5bbcc6e32451cbdaf94a0c..0000000000000000000000000000000000000000
--- a/Trigger/TrigValidation/TriggerTest/test/test_physics_pp_v7_build.sh
+++ /dev/null
@@ -1,29 +0,0 @@
-#!/bin/bash
-
-# art-description: Physics v7 TriggerTest on MC
-# art-type: build
-# art-include: 21.1/AthenaP1
-# art-include: 21.0/Athena
-# art-include: 21.0-TrigMC/Athena
-# art-include: master/Athena
-# art-output: HLTChain.txt
-# art-output: HLTTE.txt
-# art-output: L1AV.txt
-# art-output: HLTconfig_*.xml
-# art-output: L1Topoconfig*.xml
-# art-output: LVL1config*.xml
-# art-output: *.log
-# art-output: costMonitoring_*
-# art-output: *.root
-# art-output: ntuple.pmon.gz
-# art-output: *perfmon*
-# art-output: TotalEventsProcessed.txt
-# art-output: *.regtest.new
-
-export NAME="physics_pp_v7_build"
-export MENU="Physics_pp_v7"
-export EVENTS="5"
-export COST_MONITORING="False"
-
-source exec_athena_art_trigger_validation.sh
-source exec_art_triggertest_post.sh
diff --git a/Trigger/TrigValidation/TriggerTest/test/test_physics_pp_v7_chainorder_build.sh b/Trigger/TrigValidation/TriggerTest/test/test_physics_pp_v7_chainorder_build.sh
deleted file mode 100755
index 372c3b1fdb3cb4a094b16bef3b99dadc1de452b1..0000000000000000000000000000000000000000
--- a/Trigger/TrigValidation/TriggerTest/test/test_physics_pp_v7_chainorder_build.sh
+++ /dev/null
@@ -1,44 +0,0 @@
-#!/bin/bash
-
-# art-description: TriggerTest on changes coming through the order of execution
-# art-type: build
-# art-include: 21.1/AthenaP1
-# art-include: 21.0/Athena
-# art-include: 21.0-TrigMC/Athena
-# art-include: master/Athena
-# art-output: HLTChain.txt
-# art-output: HLTTE.txt
-# art-output: L1AV.txt
-# art-output: HLTconfig*.xml
-# art-output: L1Topoconfig*.xml
-# art-output: LVL1config*.xml
-# art-output: *.log
-# art-output: costMonitoring_*
-# art-output: *.root
-# art-output: ntuple.pmon.gz
-# art-output: *perfmon*
-# art-output: TotalEventsProcessed.txt
-# art-output: *.regtest.new
-
-export NAME="physics_pp_v7_chainorder_build"
-export MENU="Physics_pp_v7"
-export EVENTS="10"
-export EXTRA="chainOrderOption=-1;"
-export COST_MONITORING="False"
-
-# Run with ascending
-source exec_athena_art_trigger_validation.sh
-mv expert-monitoring.root expert-monitoring-ascend.root
-
-export EXTRA="chainOrderOption=1;"
-
-# Run with decending
-export JOB_LOG_2=${JOB_LOG%%.*}2.${JOB_LOG#*.}
-export JOB_LOG=${JOB_LOG_2}
-source exec_athena_art_trigger_validation.sh
-
-timeout 10m rootcomp.py expert-monitoring-ascend.root expert-monitoring.root | tee rootcompout.log
-echo "art-result: ${PIPESTATUS[0]} RootComp" 
-
-trigtest_checkcounts.sh 0 expert-monitoring-ascend.root HLT | tee checkcountout.log
-echo "art-result: ${PIPESTATUS[0]} CheckCounts"
diff --git a/Trigger/TrigValidation/TriggerTest/test/test_physics_pp_v7_grid.sh b/Trigger/TrigValidation/TriggerTest/test/test_physics_pp_v7_grid.sh
deleted file mode 100755
index 1bc8e0df879c76f58e1c842637a451e49c7f0922..0000000000000000000000000000000000000000
--- a/Trigger/TrigValidation/TriggerTest/test/test_physics_pp_v7_grid.sh
+++ /dev/null
@@ -1,29 +0,0 @@
-#!/bin/bash
-
-# art-description: Physics v7 TriggerTest on MC
-# art-type: grid
-# art-include: 21.1/AthenaP1
-# art-include: 21.0/Athena
-# art-include: 21.3/Athena
-# art-include: 21.0-TrigMC/Athena
-# art-include: master/Athena
-# art-output: HLTChain.txt
-# art-output: HLTTE.txt
-# art-output: L1AV.txt
-# art-output: HLTconfig*.xml
-# art-output: L1Topoconfig*.xml
-# art-output: LVL1config*.xml
-# art-output: *.log
-# art-output: costMonitoring_*
-# art-output: *.root
-# art-output: ntuple.pmon.gz
-# art-output: *perfmon*
-# art-output: TotalEventsProcessed.txt
-# art-output: *.regtest.new
-
-export NAME="physics_pp_v7_grid"
-export MENU="Physics_pp_v7"
-export EVENTS="500"
-
-source exec_athena_art_trigger_validation.sh
-source exec_art_triggertest_post.sh
diff --git a/Trigger/TrigValidation/TriggerTest/test/test_physics_pp_v7_aod_grid.sh b/Trigger/TrigValidation/TriggerTest/test/test_physics_pp_v7_primaries_aod_grid.sh
similarity index 89%
rename from Trigger/TrigValidation/TriggerTest/test/test_physics_pp_v7_aod_grid.sh
rename to Trigger/TrigValidation/TriggerTest/test/test_physics_pp_v7_primaries_aod_grid.sh
index 774978c999f7d588dea3ffcdcec3ac950c8293ec..32edfc36bca00349d5ba16681210a3869ac76757 100755
--- a/Trigger/TrigValidation/TriggerTest/test/test_physics_pp_v7_aod_grid.sh
+++ b/Trigger/TrigValidation/TriggerTest/test/test_physics_pp_v7_primaries_aod_grid.sh
@@ -20,8 +20,8 @@
 # art-output: TotalEventsProcessed.txt
 # art-output: *.regtest.new
 
-export NAME="physics_pp_v7_aod_grid"
-export MENU="Physics_pp_v7"
+export NAME="physics_pp_v7_primaries_aod_grid"
+export MENU="Physics_pp_v7_primaries"
 export EVENTS="500"
 export JOBOPTION="TriggerTest/testCommonSliceAthenaTrigRDOtoAOD.py"
 
diff --git a/Trigger/TrigValidation/TriggerTest/test/test_physics_pp_v7_tight_grid.sh b/Trigger/TrigValidation/TriggerTest/test/test_physics_pp_v7_tight_grid.sh
deleted file mode 100755
index 718af8648f003992efbffa402dbc0bf2fa7f27fd..0000000000000000000000000000000000000000
--- a/Trigger/TrigValidation/TriggerTest/test/test_physics_pp_v7_tight_grid.sh
+++ /dev/null
@@ -1,28 +0,0 @@
-#!/bin/bash
-
-# art-description: Physics v7 tight TriggerTest on MC
-# art-type: grid
-# art-include: 21.1/AthenaP1
-# art-include: 21.0/Athena
-# art-include: 21.0-TrigMC/Athena
-# art-include: master/Athena
-# art-output: HLTChain.txt
-# art-output: HLTTE.txt
-# art-output: L1AV.txt
-# art-output: HLTconfig*.xml
-# art-output: L1Topoconfig*.xml
-# art-output: LVL1config*.xml
-# art-output: *.log
-# art-output: costMonitoring_*
-# art-output: *.root
-# art-output: ntuple.pmon.gz
-# art-output: *perfmon*
-# art-output: TotalEventsProcessed.txt
-# art-output: *.regtest.new
-
-export NAME="physics_pp_v7_tight_grid"
-export MENU="Physics_pp_v7_tight_physics_prescale"
-export EVENTS="500"
-
-source exec_athena_art_trigger_validation.sh
-source exec_art_triggertest_post.sh
diff --git a/Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_ftk_rdotoaod_build.sh b/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_ftk_rdotoaod_build.sh
similarity index 76%
rename from Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_ftk_rdotoaod_build.sh
rename to Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_ftk_rdotoaod_build.sh
index 43aa8952a3c0fd065b63f303ec97f508f38b3c72..9c7660120189e3a9ea0d9752c64d4109bcb7c7b4 100755
--- a/Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_ftk_rdotoaod_build.sh
+++ b/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_ftk_rdotoaod_build.sh
@@ -1,13 +1,8 @@
 #!/bin/bash
 
 # art-description: Trigger MC pp v7 RDO to AOD test FTK
 # art-type: build
-# art-include: 21.0/Athena
-# art-include: 21.3/Athena
-# art-include: 21.0-TrigMC/Athena
 # art-include: master/Athena
-# art-include: 21.1/AthenaP1
-# art-include: 21.1-dev/AthenaP1
 # art-output: *check*
 # art-output: HLTChain.txt
 # art-output: HLTTE.txt
@@ -24,11 +19,11 @@
 # art-output: AOD.pool.root.checkFiletrigSize.txt
 # art-output: *.regtest.new
 
-export NAME="mc_pp_v7_ftk_rdotoaod_build"
+export NAME="physics_pp_v7_primaries_ftk_rdotoaod_build"
 export INPUT="ftk"
 export COST_MONITORING="False"
 export TEST="TrigAnalysisTest"
-export MENU="MC_pp_v7"
+export MENU="Physics_pp_v7_primaries"
 export EVENTS="3"
 export JOBOPTION="TrigAnalysisTest/testAthenaTrigRDOtoAOD.py"
 export EXTRA="from TriggerJobOpts.TriggerFlags import TriggerFlags;TriggerFlags.doFTK=True;from RecExConfig.RecFlags import rec;rec.doFTK.set_Value_and_Lock(True);"
@@ -1,13 +1,8 @@
 #!/bin/bash
 
-# art-description: Trigger MC pp v7 RDO to AOD test FTK
+# art-description: Trigger v7 primaries RDO to AOD test FTK
 # art-type: build
diff --git a/Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_ftk_rdotoaod_grid.sh b/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_ftk_rdotoaod_grid.sh
similarity index 76%
rename from Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_ftk_rdotoaod_grid.sh
rename to Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_ftk_rdotoaod_grid.sh
index 6f3d1c4d16d3f1a7b9a6448c3088153cbd54398c..e1d16809aad0b1137ad382bf3220db3ff60fba5c 100755
--- a/Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_ftk_rdotoaod_grid.sh
+++ b/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_ftk_rdotoaod_grid.sh
@@ -1,13 +1,8 @@
 #!/bin/bash
 
 # art-description: Trigger MC pp v7 RDO to AOD test with FTK
 # art-type: grid
-# art-include: 21.0/Athena
-# art-include: 21.3/Athena
-# art-include: 21.0-TrigMC/Athena
 # art-include: master/Athena
-# art-include: 21.1/AthenaP1
-# art-include: 21.1-dev/AthenaP1
 # art-output: *check*
 # art-output: HLTChain.txt
 # art-output: HLTTE.txt
@@ -24,11 +19,11 @@
 # art-output: AOD.pool.root.checkFiletrigSize.txt
 # art-output: *.regtest.new
 
-export NAME="mc_pp_v7_ftk_rdotoaod_grid"
+export NAME="physics_pp_v7_primaries_ftk_rdotoaod_grid"
 export INPUT="ftk"
 export COST_MONITORING="False"
 export TEST="TrigAnalysisTest"
-export MENU="MC_pp_v7"
+export MENU="Physics_pp_v7_primaries"
 export EVENTS="100"
 export JOBOPTION="TrigAnalysisTest/testAthenaTrigRDOtoAOD.py"
 export EXTRA="from TriggerJobOpts.TriggerFlags import TriggerFlags;TriggerFlags.doFTK=True;from RecExConfig.RecFlags import rec;rec.doFTK.set_Value_and_Lock(True);"
@@ -1,13 +1,8 @@
 #!/bin/bash
 
-# art-description: Trigger MC pp v7 RDO to AOD test with FTK
+# art-description: Trigger v7 primaries RDO to AOD test with FTK
 # art-type: grid
diff --git a/Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_ftk_rdotoesdaod_build.sh b/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_ftk_rdotoesdaod_build.sh
similarity index 72%
rename from Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_ftk_rdotoesdaod_build.sh
rename to Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_ftk_rdotoesdaod_build.sh
index 0fdd410b9256ca09a07e192f5753e384d047254f..227d06c03ebdb403028169010339c938e6a3779b 100755
--- a/Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_ftk_rdotoesdaod_build.sh
+++ b/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_ftk_rdotoesdaod_build.sh
@@ -1,13 +1,8 @@
 #!/bin/bash
 
 # art-description: Trigger MC pp v7 RDO to ESD and AOD test, plus extra tests using these files. With FTK
 # art-type: build
-# art-include: 21.0/Athena
-# art-include: 21.3/Athena
-# art-include: 21.0-TrigMC/Athena
 # art-include: master/Athena
-# art-include: 21.1/AthenaP1
-# art-include: 21.1-dev/AthenaP1
 # art-output: *check*
 # art-output: HLTChain.txt
 # art-output: HLTTE.txt
@@ -22,11 +17,11 @@
 # art-output: TotalEventsProcessed.txt
 # art-output: *.regtest.new
 
-export NAME="mc_pp_v7_ftk_rdotoesdaod_build"
+export NAME="physics_pp_v7_primaries_ftk_rdotoesdaod_build"
 export INPUT="ftk"
 export COST_MONITORING="False"
 export TEST="TrigAnalysisTest"
-export MENU="MC_pp_v7"
+export MENU="Physics_pp_v7_primaries"
 export EVENTS="3"
 export JOBOPTION="TrigAnalysisTest/testAthenaTrigRDOtoESDAOD.py"
 export EXTRA="from TriggerJobOpts.TriggerFlags import TriggerFlags;TriggerFlags.doFTK=True;from RecExConfig.RecFlags import rec;rec.doFTK.set_Value_and_Lock(True);"
@@ -1,13 +1,8 @@
 #!/bin/bash
 
-# art-description: Trigger MC pp v7 RDO to ESD and AOD test, plus extra tests using these files. With FTK
+# art-description: Trigger v7 primaries RDO to ESD and AOD test, plus extra tests using these files. With FTK
 # art-type: build
diff --git a/Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_ftk_rdotoesdaod_grid.sh b/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_ftk_rdotoesdaod_grid.sh
similarity index 78%
rename from Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_ftk_rdotoesdaod_grid.sh
rename to Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_ftk_rdotoesdaod_grid.sh
index cbf91c60e7ed0a5a7aa4869e3fa5a1bbc00d8c2b..c938457e8441129e0f4013393eac788fc021bdc6 100755
--- a/Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_ftk_rdotoesdaod_grid.sh
+++ b/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_ftk_rdotoesdaod_grid.sh
@@ -1,11 +1,8 @@
 #!/bin/bash
 
 # art-description: Trigger MC pp v7 RDO to ESD and AOD test, plus extra tests using these files. With FTK
 # art-type: grid
-# art-include: 21.0/Athena
-# art-include: 21.3/Athena
 # art-include: master/Athena
-# art-include: 21.1/AthenaP1
 # art-output: *check*
 # art-output: HLTChain.txt
 # art-output: HLTTE.txt
@@ -23,11 +20,11 @@
 # art-output: *.regtest.new
 
 
-export NAME="mc_pp_v7_ftk_rdotoesdaod_grid"
+export NAME="physics_pp_v7_primaries_ftk_rdotoesdaod_grid"
 export INPUT="ftk"
 export COST_MONITORING="False"
 export TEST="TrigAnalysisTest"
-export MENU="MC_pp_v7"
+export MENU="Physics_pp_v7_primaries"
 export EVENTS="100"
 export JOBOPTION="TrigAnalysisTest/testAthenaTrigRDOtoESDAOD.py"
 export EXTRA="from TriggerJobOpts.TriggerFlags import TriggerFlags;TriggerFlags.doFTK=True;from RecExConfig.RecFlags import rec;rec.doFTK.set_Value_and_Lock(True);"
@@ -1,11 +1,8 @@
 #!/bin/bash
 
-# art-description: Trigger MC pp v7 RDO to ESD and AOD test, plus extra tests using these files. With FTK
+# art-description: Trigger v7 primaries RDO to ESD and AOD test, plus extra tests using these files. With FTK
 # art-type: grid
diff --git a/Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_rdotoaod_build.sh b/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_rdotoaod_build.sh
similarity index 78%
rename from Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_rdotoaod_build.sh
rename to Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_rdotoaod_build.sh
index 7dd0408b2805563603a6fff2cb05a84a53da0606..ea1b9566dedde53db05507a73057acd266c424ce 100755
--- a/Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_rdotoaod_build.sh
+++ b/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_rdotoaod_build.sh
@@ -1,11 +1,8 @@
 #!/bin/bash
 
 # art-description: Trigger MC pp v7 RDO to AOD test
 # art-type: build
-# art-include: 21.0/Athena
-# art-include: 21.3/Athena
 # art-include: master/Athena
-# art-include: 21.1/AthenaP1
 # art-output: *check*
 # art-output: HLTChain.txt
 # art-output: HLTTE.txt
@@ -22,10 +19,10 @@
 # art-output: AOD.pool.root.checkFiletrigSize.txt
 # art-output: *.regtest.new
 
-export NAME="mc_pp_v7_rdotoaod_build"
+export NAME="physics_pp_v7_primaries_rdotoaod_build"
 export COST_MONITORING="False"
 export TEST="TrigAnalysisTest"
-export MENU="MC_pp_v7"
+export MENU="Physics_pp_v7_primaries"
 export EVENTS="3"
 export JOBOPTION="TrigAnalysisTest/testAthenaTrigRDOtoAOD.py"
 
@@ -1,11 +1,8 @@
 #!/bin/bash
 
-# art-description: Trigger MC pp v7 RDO to AOD test
+# art-description: Trigger v7 primaries RDO to AOD test
 # art-type: build
diff --git a/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_rdotoaod_grid.sh b/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_rdotoaod_grid.sh
similarity index 80%
rename from Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_rdotoaod_grid.sh
rename to Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_rdotoaod_grid.sh
index f42e1c4b2e1f0eecdfef06ad29c67c4c26352c05..b9264d1cec8ab30413d6d5cd76bc0879c5b508c5 100755
--- a/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_rdotoaod_grid.sh
+++ b/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_rdotoaod_grid.sh
@@ -1,11 +1,8 @@
 #!/bin/bash
 
 # art-description: Trigger Physics pp v7 RDO to AOD test
 # art-type: grid
-# art-include: 21.0/Athena
-# art-include: 21.3/Athena
 # art-include: master/Athena
-# art-include: 21.1/AthenaP1
 # art-output: *check*
 # art-output: HLTChain.txt
 # art-output: HLTTE.txt
@@ -22,7 +19,7 @@
 # art-output: AOD.pool.root.checkFiletrigSize.txt
 # art-output: *.regtest.new
 
-export NAME="physics_pp_v7_rdotoaod_grid"
+export NAME="physics_pp_v7_primaries_rdotoaod_grid"
 export COST_MONITORING="False"
 export TEST="TrigAnalysisTest"
 export MENU="Physics_pp_v7_primaries"
@@ -1,11 +1,8 @@
 #!/bin/bash
 
-# art-description: Trigger Physics pp v7 RDO to AOD test
+# art-description: Trigger v7 primaries RDO to AOD test
 # art-type: grid
diff --git a/Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_rdotoaodslim_build.sh b/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_rdotoaodslim_build.sh
similarity index 76%
rename from Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_rdotoaodslim_build.sh
rename to Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_rdotoaodslim_build.sh
index 1f45f9e87c09e9043cc7c08cd59186e08320781d..8c72593f377fef182ad1c0739c44168e73acc214 100755
--- a/Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_rdotoaodslim_build.sh
+++ b/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_rdotoaodslim_build.sh
@@ -1,11 +1,8 @@
 #!/bin/bash
 
 # art-description: Trigger MC pp v7 RDO to AODSLIM
 # art-type: build
-# art-include: 21.0/Athena
-# art-include: 21.3/Athena
 # art-include: master/Athena
-# art-include: 21.1/AthenaP1
 # art-output: *check*
 # art-output: HLTChain.txt
 # art-output: HLTTE.txt
@@ -20,10 +17,10 @@
 # art-output: TotalEventsProcessed.txt
 # art-output: *.regtest.new
 
-export NAME="mc_pp_v7_rdotoaodslim_build"
+export NAME="physics_pp_v7_primaries_rdotoaodslim_build"
 export COST_MONITORING="False"
 export TEST="TrigAnalysisTest"
-export MENU="MC_pp_v7"
+export MENU="Physics_pp_v7_primaries"
 export EVENTS="3"
 export JOBOPTION="TrigAnalysisTest/testAthenaTrigRDOtoAODSLIM.py"
 
@@ -1,11 +1,8 @@
 #!/bin/bash
 
-# art-description: Trigger MC pp v7 RDO to AODSLIM
+# art-description: Trigger v7 primaries RDO to AODSLIM
 # art-type: build
diff --git a/Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_rdotobstoesd_build.sh b/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_rdotobstoesd_build.sh
similarity index 74%
rename from Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_rdotobstoesd_build.sh
rename to Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_rdotobstoesd_build.sh
index 2e97fafe16d0616a5fe954c313384a1c37e73c82..e14fb4f931ff4fa53ed410736e1f024a0c5e4ff6 100755
--- a/Trigger/TrigValidation/TrigAnalysisTest/test/test_mc_pp_v7_rdotobstoesd_build.sh
+++ b/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_rdotobstoesd_build.sh
@@ -1,11 +1,8 @@
 #!/bin/bash
 
 # art-description: Trigger MC pp v7 RDO to BS and BS to ESD test
 # art-type: build
-# art-include: 21.0/Athena
-# art-include: 21.3/Athena
 # art-include: master/Athena
-# art-include: 21.1/AthenaP1
 # art-output: *check*
 # art-output: HLTChain.txt
 # art-output: HLTTE.txt
@@ -20,15 +17,15 @@
 # art-output: TotalEventsProcessed.txt
 # art-output: *.regtest.new
 
-export NAME="mc_pp_v7_rdotobstoesd_build"
+export NAME="physics_pp_v7_primaries_rdotobstoesd_build"
 export COST_MONITORING="False"
 export TEST="TrigAnalysisTest"
-export MENU="MC_pp_v7"
+export MENU="Physics_pp_v7_primaries"
 export EVENTS="3"
 export JOBOPTION="TrigAnalysisTest/testAthenaTrigRDOtoBS.py"
 
 source exec_athena_art_trigger_validation.sh
 athena.py -c "jp.AthenaCommonFlags.BSRDOInput=['raw.data']" TrigAnalysisTest/testAthenaTrigBStoESD.py | tee ${JOB_LOG%%.*}.BStoESD.${JOB_LOG#*.}
-echo "art-result: ${PIPESTATUS[0]} athena.BStoESD"
+echo "art-result: ${PIPESTATUS[0]} ${JOB_LOG%%.*}BStoESD"
 
 source exec_art_triggertest_post.sh
@@ -1,11 +1,8 @@
 #!/bin/bash
 
-# art-description: Trigger MC pp v7 RDO to BS and BS to ESD test
+# art-description: Trigger v7 primaries RDO to BS and BS to ESD test
 # art-type: build
diff --git a/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_rdotoesdaod_build.sh b/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_rdotoesdaod_build.sh
similarity index 75%
rename from Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_rdotoesdaod_build.sh
rename to Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_rdotoesdaod_build.sh
index 8c6a483d769cdbd3db76bb0abdb281c23736b24f..5319932951a8f59a5f77f0c03eb14767f9ad2edc 100755
--- a/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_rdotoesdaod_build.sh
+++ b/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_rdotoesdaod_build.sh
@@ -1,11 +1,8 @@
 #!/bin/bash
 
 # art-description: Trigger Physics pp v7 RDO to ESD and AOD test, plus extra tests using these files
 # art-type: build
-# art-include: 21.0/Athena
-# art-include: 21.3/Athena
 # art-include: master/Athena
-# art-include: 21.1/AthenaP1
 # art-output: *check*
 # art-output: HLTChain.txt
 # art-output: HLTTE.txt
@@ -20,7 +17,7 @@
 # art-output: TotalEventsProcessed.txt
 # art-output: *.regtest.new
 
-export NAME="physics_pp_v7_rdotoesdaod_build"
+export NAME="physics_pp_v7_primaries_rdotoesdaod_build"
 export COST_MONITORING="False"
 export TEST="TrigAnalysisTest"
 export MENU="Physics_pp_v7_primaries"
@@ -1,11 +1,8 @@
 #!/bin/bash
 
-# art-description: Trigger Physics pp v7 RDO to ESD and AOD test, plus extra tests using these files
+# art-description: Trigger v7 primaries RDO to ESD and AOD test, plus extra tests using these files
 # art-type: build
diff --git a/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_rdotoesdaod_grid.sh b/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_rdotoesdaod_grid.sh
similarity index 77%
rename from Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_rdotoesdaod_grid.sh
rename to Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_rdotoesdaod_grid.sh
index 6532b427227f6dae5a18fb7e957bd5f90bbc4fd9..092df0cf3182b4f9d5fc884b077c2d01c78852fb 100755
--- a/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_rdotoesdaod_grid.sh
+++ b/Trigger/TrigValidation/TrigAnalysisTest/test/test_physics_pp_v7_primaries_rdotoesdaod_grid.sh
@@ -1,11 +1,8 @@
 #!/bin/bash
 
 # art-description: Trigger Physics pp v7 RDO to ESD and AOD test, plus extra tests using these files
 # art-type: grid
-# art-include: 21.0/Athena
-# art-include: 21.3/Athena
 # art-include: master/Athena
-# art-include: 21.1/AthenaP1
 # art-output: *check*
 # art-output: HLTChain.txt
 # art-output: HLTTE.txt
@@ -22,7 +19,8 @@
 # art-output: AOD.pool.root.checkFiletrigSize.txt
 # art-output: *.regtest.new
 
-export NAME="physics_pp_v7_rdotoesdaod_grid"
+
+export NAME="physics_pp_v7_primaries_rdotoesdaod_grid"
 export COST_MONITORING="False"
 export TEST="TrigAnalysisTest"
 export MENU="Physics_pp_v7_primaries"
@@ -1,11 +1,8 @@
 #!/bin/bash
 
-# art-description: Trigger Physics pp v7 RDO to ESD and AOD test, plus extra tests using these files
+# art-description: Trigger v7 primaries RDO to ESD and AOD test, plus extra tests using these files
 # art-type: grid